<?php

return array(
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Cap',
    'Edit' => 'Edita',
    'Remove' => 'Elimina',
    'Yes' => 'Si',
    'No' => 'No',
    'cancel' => 'cancel·la',
    'or' => 'o',
    'Yellow' => 'Groc',
    'Blue' => 'Blau',
    'Green' => 'Verd',
    'Purple' => 'Lil·la',
    'Red' => 'Vermell',
    'Orange' => 'Taronja',
    'Grey' => 'Gris',
    'Brown' => 'Marró',
    'Deep Orange' => 'Taronja fosc',
    'Dark Grey' => 'Gris fosc',
    'Pink' => 'Rosa',
    'Teal' => 'Turquessa',
    'Cyan' => 'Cian',
    'Lime' => 'Lima',
    'Light Green' => 'Verd clar',
    'Amber' => 'Ambre',
    'Save' => 'Desa',
    'Login' => 'Inicia la sessió',
    'Official website:' => 'Pàgina web oficial:',
    'Unassigned' => 'Sense assignar',
    'View this task' => 'Veure aquesta tasca',
    'Remove user' => 'Eliminar usuari',
    'Do you really want to remove this user: "%s"?' => 'Vols eliminar aquest usuari: "%s"?',
    'All users' => 'Tots els usuaris',
    'Username' => 'Nom d\'usuari',
    'Password' => 'Contrasenya',
    'Administrator' => 'Administrador',
    'Sign in' => 'Accedeix',
    'Users' => 'Usuaris',
    'Forbidden' => 'Prohibit',
    'Access Forbidden' => 'Accés prohibit',
    'Edit user' => 'Edita usuaris',
    'Logout' => 'Tanca sessió',
    'Bad username or password' => 'Usuari o contrasenya no existeix',
    'Edit project' => 'Edita el projecte',
    'Name' => 'Nom',
    'Projects' => 'Projectes',
    'No project' => 'Cap projecte',
    'Project' => 'Projecte',
    'Status' => 'Estat',
    'Tasks' => 'Tasques',
    'Board' => 'Tauler',
    'Actions' => 'Accions',
    'Inactive' => 'Inactiu',
    'Active' => 'Actiu',
    'Unable to update this board.' => 'No es pot actualitzar aquest tauler.',
    'Disable' => 'Desactivar',
    'Enable' => 'Habilita',
    'New project' => 'Nou projecte',
    'Do you really want to remove this project: "%s"?' => 'Vols eliminar aquest projecte: "%s"?',
    'Remove project' => 'Elimina projecte',
    'Edit the board for "%s"' => 'Edita el tauler de "%s"',
    'Add a new column' => 'Afegeix una nova columna',
    'Title' => 'Títol',
    'Assigned to %s' => 'Assignat a %s',
    'Remove a column' => 'Eliminar una columna',
    'Unable to remove this column.' => 'No es pot eliminar aquesta columna.',
    'Do you really want to remove this column: "%s"?' => 'Vols eliminar aquesta columna: "%s"?',
    'Settings' => 'Configuració',
    'Application settings' => 'Configuració de l\'aplicació',
    'Language' => 'Idioma',
    'Webhook token:' => 'Web hook token:',
    'API token:' => 'Token de l\'API:',
    'Database size:' => 'Mida de la base de dades:',
    'Download the database' => 'Descarregar la base de dades',
    'Optimize the database' => 'Optimitzar la base de dades',
    '(VACUUM command)' => '(Comanda VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Arxiu comprimit gzip SQLite)',
    'Close a task' => 'Tancar una tasca',
    'Column' => 'Columna',
    'Color' => 'Color',
    'Assignee' => 'Assignat a',
    'Create another task' => 'Crear una altra tasca',
    'New task' => 'Nova tasca',
    'Open a task' => 'Obrir una tasca',
    'Do you really want to open this task: "%s"?' => 'Vols obrir aquesta tasca: "%s"?',
    'Back to the board' => 'Torna al tauler',
    'There is nobody assigned' => 'No hi ha ningú assignat',
    'Column on the board:' => 'Columna al tauler:',
    'Close this task' => 'Tanca aquesta tasca',
    'Open this task' => 'Obre aquesta tasca',
    'There is no description.' => 'No hi ha cap descripció.',
    'Add a new task' => 'Afegeix una nova tasca',
    'The username is required' => 'Es requereix el nom d\'usuari',
    'The maximum length is %d characters' => 'La longitud màxima és de %d caràcters',
    'The minimum length is %d characters' => 'La longitud mínima és %d caràcters',
    'The password is required' => 'La contrasenya és necessària',
    'This value must be an integer' => 'Aquest valor ha de ser un nombre enter',
    'The username must be unique' => 'El nom d\'usuari ha de ser únic',
    'The user id is required' => 'Es requereix que l\'ID d\'usuari',
    'Passwords don\'t match' => 'Les contrasenyes no coincideixen',
    'The confirmation is required' => 'Es requereix la confirmació',
    'The project is required' => 'Es requereix el projecte',
    'The id is required' => 'Es requereix que l\'ID',
    'The project id is required' => 'Es requereix que l\'identificador del projecte',
    'The project name is required' => 'Es requereix el nom del projecte',
    'The title is required' => 'Es requereix el títol',
    'Settings saved successfully.' => 'La configuració es va guardar amb èxit.',
    'Unable to save your settings.' => 'No es pot desar la configuració.',
    'Database optimization done.' => 'Optimització de bases de dades realitza.',
    'Your project has been created successfully.' => 'El seu projecte s\'han creat amb èxit.',
    'Unable to create your project.' => 'No es pot crear el projecte.',
    'Project updated successfully.' => 'Projecte actualitzat correctament.',
    'Unable to update this project.' => 'No es pot actualitzar aquest projecte.',
    'Unable to remove this project.' => 'No es pot eliminar aquest projecte.',
    'Project removed successfully.' => 'Projecte eliminat correctament.',
    'Project activated successfully.' => 'Projecte activat correctament.',
    'Unable to activate this project.' => 'No es pot activar aquest projecte.',
    'Project disabled successfully.' => 'Projecte deshabilitat amb èxit.',
    'Unable to disable this project.' => 'No és possible desactivar aquest projecte.',
    'Unable to open this task.' => 'No es pot obrir aquesta tasca.',
    'Task opened successfully.' => 'Tasca oberta amb èxit.',
    'Unable to close this task.' => 'No es pot tancar aquesta tasca.',
    'Task closed successfully.' => 'Tasca tancada amb èxit.',
    'Unable to update your task.' => 'No es pot actualitzar la seva tasca.',
    'Task updated successfully.' => 'Tasca actualitzada correctament.',
    'Unable to create your task.' => 'No es pot crear la tasca.',
    'Task created successfully.' => 'Tasca creada correctament.',
    'User created successfully.' => 'L\'usuari ha creat correctament.',
    'Unable to create your user.' => 'No es pot crear l\'usuari.',
    'User updated successfully.' => 'Usuari actualitzat correctament.',
    'User removed successfully.' => 'Usuari eliminat correctament.',
    'Unable to remove this user.' => 'No es pot eliminar aquest usuari.',
    'Board updated successfully.' => 'Tauler actualitzat correctament.',
    'Ready' => 'Preparat',
    'Backlog' => 'Pendent',
    'Work in progress' => 'En curs',
    'Done' => 'Fet',
    'Application version:' => 'Versió de l\'aplicació:',
    'Id' => 'Identificació',
    'Public link' => 'Enllaç públic',
    'Timezone' => 'Zona horària',
    'Sorry, I didn\'t find this information in my database!' => 'No s\'ha trobat la informació a la base de dades!',
    'Page not found' => 'Pàgina no trobada',
    'Complexity' => 'Dificultat',
    'Task limit' => 'Límit de tasques',
    'Task count' => 'Recompte de tasques',
    'User' => 'Usuari',
    'Comments' => 'Comentaris',
    'Comment is required' => 'Es requereix comentari',
    'Comment added successfully.' => 'Comentari afegit amb èxit.',
    'Unable to create your comment.' => 'No es pot crear el seu comentari.',
    'Due Date' => 'Data de venciment',
    'Invalid date' => 'Data no vàlida',
    'Automatic actions' => 'Accions automàtiques',
    'Your automatic action has been created successfully.' => 'La seva acció automàtica s\'han creat amb èxit.',
    'Unable to create your automatic action.' => 'No es pot crear la seva acció automàtica.',
    'Remove an action' => 'Eliminar una acció',
    'Unable to remove this action.' => 'No es pot eliminar aquesta acció.',
    'Action removed successfully.' => 'Acció eliminat correctament.',
    'Automatic actions for the project "%s"' => 'Accions automàtiques per al projecte "%s"',
    'Add an action' => 'Afegeix una acció',
    'Event name' => 'Nom de l\'esdeveniment',
    'Action' => 'Acció',
    'Event' => 'Esdeveniment',
    'When the selected event occurs execute the corresponding action.' => 'Quan es produeix l\'esdeveniment seleccionat executar l\'acció corresponent.',
    'Next step' => 'Següent pas',
    'Define action parameters' => 'Definir paràmetres d\'acció',
    'Do you really want to remove this action: "%s"?' => 'Vols eliminar aquesta acció: "%s"?',
    'Remove an automatic action' => 'Eliminar una acció automàtica',
    'Assign the task to a specific user' => 'Assignar la tasca a un usuari específic',
    'Assign the task to the person who does the action' => 'Assignar la tasca a la persona que fa l\'acció',
    'Duplicate the task to another project' => 'Duplica la tasca a un altre projecte',
    'Move a task to another column' => 'Mou una tasca a una altra columna',
    'Task modification' => 'Modificació de tasques',
    'Task creation' => 'Creació de tasques',
    'Closing a task' => 'El tancament d\'una tasca',
    'Assign a color to a specific user' => 'Assignar un color a un usuari específic',
    'Position' => 'Posició',
    'Duplicate to project' => 'Duplica a un altre projecte',
    'Duplicate' => 'Duplica',
    'Link' => 'Enllaç',
    'Comment updated successfully.' => 'Comentari actualitzat correctament.',
    'Unable to update your comment.' => 'No es pot actualitzar el seu comentari.',
    'Remove a comment' => 'Retirar un comentari',
    'Comment removed successfully.' => 'Comentari eliminat correctament.',
    'Unable to remove this comment.' => 'No es pot eliminar aquest comentari.',
    'Do you really want to remove this comment?' => 'Vols eliminar aquest comentari?',
    'Current password for the user "%s"' => 'Contrasenya actual per a l\'usuari "%s"',
    'The current password is required' => 'Es requereix la contrasenya actual',
    'Wrong password' => 'Contrasenya incorrecta',
    'Unknown' => 'Desconegut',
    'Last logins' => 'Últims inicis de sessió',
    'Login date' => 'Data d\'inici de sessió',
    'Authentication method' => 'Mètode d\'autenticació',
    'IP address' => 'Adreça IP',
    'User agent' => 'Agent d\'usuari',
    'Persistent connections' => 'Les connexions persistents',
    'No session.' => 'Cap sessió.',
    'Expiration date' => 'Data de caducitat',
    'Remember Me' => 'Recorda\'m',
    'Creation date' => 'Data de creació',
    'Everybody' => 'Tothom',
    'Open' => 'Obert',
    'Closed' => 'Tancat',
    'Search' => 'Cerca',
    'Nothing found.' => 'No s\'ha trobat res.',
    'Due date' => 'Data de venciment',
    'Description' => 'Descripció',
    '%d comments' => '%d comentaris',
    '%d comment' => '%d comentari',
    'Email address invalid' => 'Adreça de correu electrònic no vàlida',
    'Your external account is not linked anymore to your profile.' => 'El seu compte extern no està vinculada més al seu perfil.',
    'Unable to unlink your external account.' => 'No és possible desvincular el compte extern.',
    'External authentication failed' => 'L\'autenticació externa va fallar',
    'Your external account is linked to your profile successfully.' => 'El seu compte extern està vinculada al seu perfil correctament.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Tasca eliminat correctament.',
    'Unable to remove this task.' => 'No es pot eliminar aquesta tasca.',
    'Remove a task' => 'Treure una tasca',
    'Do you really want to remove this task: "%s"?' => 'Vols eliminar aquesta tasca: "%s"?',
    'Assign automatically a color based on a category' => 'Assignar automàticament un color basat en una categoria',
    'Assign automatically a category based on a color' => 'Assignar automàticament una categoria basada en un color',
    'Task creation or modification' => 'Creació o modificació de tasques',
    'Category' => 'Categoria',
    'Category:' => 'Categoria:',
    'Categories' => 'Categories',
    'Your category has been created successfully.' => 'La seva categoria s\'han creat amb èxit.',
    'This category has been updated successfully.' => 'Aquesta categoria s\'ha actualitzat correctament.',
    'Unable to update this category.' => 'No es pot actualitzar aquesta categoria.',
    'Remove a category' => 'Eliminar una categoria',
    'Category removed successfully.' => 'Categoria eliminat correctament.',
    'Unable to remove this category.' => 'No es pot eliminar aquesta categoria.',
    'Category modification for the project "%s"' => 'Modificació de la categoria pel projecte "%s"',
    'Category Name' => 'Nom de categoria',
    'Add a new category' => 'Afegeix una nova categoria',
    'Do you really want to remove this category: "%s"?' => 'Vols eliminar aquesta categoria: "%s"?',
    'All categories' => 'Totes les categories',
    'No category' => 'sense categoria',
    'The name is required' => 'Es requereix el nom',
    'Remove a file' => 'Suprimir un fitxer',
    'Unable to remove this file.' => 'No es pot eliminar aquest arxiu.',
    'File removed successfully.' => 'Arxiu eliminat amb èxit.',
    'Attach a document' => 'Adjunta un document',
    'Do you really want to remove this file: "%s"?' => 'Vols eliminar aquesta imatge: "%s"?',
    'Attachments' => 'Adjunts',
    'Edit the task' => 'Edita la tasca',
    'Add a comment' => 'Afegeix un comentari',
    'Edit a comment' => 'Edita un comentari',
    'Summary' => 'Resum',
    'Time tracking' => 'Control d\'hores',
    'Estimate:' => 'Estimació:',
    'Spent:' => 'Utilitzat:',
    'Do you really want to remove this sub-task?' => 'Realment voleu eliminar aquesta sub-tasca?',
    'Remaining:' => 'Restant:',
    'hours' => 'hores',
    'estimated' => 'estimat',
    'Sub-Tasks' => 'Subtasques',
    'Add a sub-task' => 'Afegeix una subtasca',
    'Original estimate' => 'Estimació original',
    'Create another sub-task' => 'Crear una altra subtasca',
    'Time spent' => 'El temps dedicat',
    'Edit a sub-task' => 'Editar una subtasca',
    'Remove a sub-task' => 'Suprimir una subtasca',
    'The time must be a numeric value' => 'El temps ha de ser un valor numèric',
    'Todo' => 'Fer',
    'In progress' => 'En progrés',
    'Sub-task removed successfully.' => 'Subtasca eliminat correctament.',
    'Unable to remove this sub-task.' => 'No es pot eliminar aquesta sub-tasques.',
    'Sub-task updated successfully.' => 'Subtasca actualitzat correctament.',
    'Unable to update your sub-task.' => 'No es pot actualitzar el seu sub-tasques.',
    'Unable to create your sub-task.' => 'No es pot crear el sub-tasques.',
    'Maximum size: ' => 'Mida màxima: ',
    'Display another project' => 'Mostra un altre projecte',
    'Created by %s' => 'Creat per %s',
    'Tasks Export' => 'Exportació de tasques',
    'Start Date' => 'Data d\'inici',
    'Execute' => 'Executar',
    'Task Id' => 'ID de tasca',
    'Creator' => 'Creador',
    'Modification date' => 'Data de modificació',
    'Completion date' => 'Data de finalització',
    'Clone' => 'Clon',
    'Project cloned successfully.' => 'Projecte clonat amb èxit.',
    'Unable to clone this project.' => 'No és possible clonar aquest projecte.',
    'Enable email notifications' => 'Activa notificacions per correu electrònic',
    'Task position:' => 'Posició de la tasca:',
    'The task #%d has been opened.' => 'La tasca #%d s\'ha obert.',
    'The task #%d has been closed.' => 'La tasca #%d s\'ha tancat.',
    'Sub-task updated' => 'Subtasca actualitza',
    'Title:' => 'Títol:',
    'Status:' => 'Estat:',
    'Assignee:' => 'Assignat a:',
    'Time tracking:' => 'Control d\'hores:',
    'New sub-task' => 'Nova subtasca',
    'New attachment added "%s"' => 'Nou adjunt afegit "%s"',
    'New comment posted by %s' => 'Nou comentari Publicat per %s',
    'New comment' => 'Nou comentari',
    'Comment updated' => 'Comentari actualitzat',
    'New subtask' => 'Nova subtasca',
    'I only want to receive notifications for these projects:' => 'Vull rebre notificacions només per a aquells projectes:',
    'view the task on Kanboard' => 'Veure la tasca en Kanboard',
    'Public access' => 'Accés públic',
    'Disable public access' => 'Deshabilitar l\'accés del públic',
    'Enable public access' => 'Permetre l\'accés del públic',
    'Public access disabled' => 'L\'accés públic deshabilitat',
    'Move the task to another project' => 'Mou la tasca a un altre projecte',
    'Move to project' => 'Mou a un altre projecte',
    'Do you really want to duplicate this task?' => 'És el que realment desitja duplicar aquesta tasca?',
    'Duplicate a task' => 'Duplica una tasca',
    'External accounts' => 'Els comptes externes',
    'Account type' => 'Tipus de compte',
    'Local' => 'Local',
    'Remote' => 'Remot',
    'Enabled' => 'Habilitat',
    'Disabled' => 'Inhabilitat',
    'Login:' => 'Iniciar Sessió:',
    'Full Name:' => 'Nom complet:',
    'Email:' => 'E-mail:',
    'Notifications:' => 'Notificacions:',
    'Notifications' => 'Notificacions',
    'Account type:' => 'Tipus de compte:',
    'Edit profile' => 'Editar el perfil',
    'Change password' => 'Canvia la contrasenya',
    'Password modification' => 'Modificació de la contrasenya',
    'External authentications' => 'Autenticacions externes',
    'Never connected.' => 'Mai connectada.',
    'No external authentication enabled.' => 'No s\'habilita l\'autenticació externa.',
    'Password modified successfully.' => 'Contrasenya modificat correctament.',
    'Unable to change the password.' => 'No es pot canviar la contrasenya.',
    'Change category' => 'Canvia la categoria',
    '%s updated the task %s' => '%s ha actualitzat la tasca %s',
    '%s opened the task %s' => '%s ha obert la tasca %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s ha mogut la tasca %s a la posició #%d de la columna "%s"',
    '%s moved the task %s to the column "%s"' => '%s ha mogut la tasca %s a la columna "%s"',
    '%s created the task %s' => '%s creat la tasca %s',
    '%s closed the task %s' => '%s tancada la tasca %s',
    '%s created a subtask for the task %s' => '%s creat una subtasca de la tasca %s',
    '%s updated a subtask for the task %s' => '%s actualitzada una subtasca de la tasca %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Assignat a %s amb un temps estimat de %s/%sh',
    'Not assigned, estimate of %sh' => 'No assignat, estimat de %sh',
    '%s updated a comment on the task %s' => '%s ha actualitzat un comentari a la tasca %s',
    '%s commented the task %s' => '%s ha comentat la tasca %s',
    '%s\'s activity' => 'L\'activitat de %s',
    'RSS feed' => 'RSS feed',
    '%s updated a comment on the task #%d' => '%s s\'actualitzen un comentari a la tasca #%d',
    '%s commented on the task #%d' => '%s comentat a la tasca #%d',
    '%s updated a subtask for the task #%d' => '%s s\'actualitzen un subtasca de la tasca #%d',
    '%s created a subtask for the task #%d' => '%s creat una subtasca de la tasca #%d',
    '%s updated the task #%d' => '%s actualitzada la tasca #%d',
    '%s created the task #%d' => '%s creat la tasca #%d',
    '%s closed the task #%d' => '%s van tancar la tasca #%d',
    '%s opened the task #%d' => '%s va obrir la tasca #%d',
    'Activity' => 'Activitat',
    'Default values are "%s"' => 'Els valors per defecte son "%s"',
    'Default columns for new projects (Comma-separated)' => 'Columnes predeterminades per a nous projectes (separats per comes)',
    'Task assignee change' => 'Tasca de canvi del assignat',
    '%s changed the assignee of the task #%d to %s' => '%s va canviar el assignat de la tasca #%d de %s',
    '%s changed the assignee of the task %s to %s' => '%s va canviar el assignat de la tasca %s %s',
    'New password for the user "%s"' => 'Nova contrasenya per a l\'usuari "%s"',
    'Choose an event' => 'Tria un esdeveniment',
    'Create a task from an external provider' => 'Crear una tasca d\'un proveïdor extern',
    'Change the assignee based on an external username' => 'Canviar el assignat basat en un nom d\'usuari extern',
    'Change the category based on an external label' => 'Canviar la categoria en funció d\'una etiqueta externa',
    'Reference' => 'Referència',
    'Label' => 'Etiqueta',
    'Database' => 'Base de dades',
    'About' => 'Quant a',
    'Database driver:' => 'Controlador de base de dades:',
    'Board settings' => 'Paràmetres del tauler',
    'Webhook settings' => 'Configuració web hook',
    'Reset token' => 'Reinicia el token',
    'API endpoint:' => 'API de punt final:',
    'Refresh interval for personal board' => 'Interval d\'actualització per al tauler privada',
    'Refresh interval for public board' => 'Interval d\'actualització per al tauler pública',
    'Task highlight period' => 'Període culminant de tasques',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Període (en segons) per considerar una tasca es va modificar recentment (0 per desactivar, 2 dies de defecte)',
    'Frequency in second (60 seconds by default)' => 'Freqüència en segons (60 segons per defecte)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Freqüència en segons (0 per desactivar aquesta característica, 10 segons per defecte)',
    'Application URL' => 'URL de l\'aplicació',
    'Token regenerated.' => 'Token regenerat.',
    'Date format' => 'Format de dates',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Sempre s\'accepta el format ISO, exemple "%s" i "%s"',
    'New personal project' => 'Nou projecte privat',
    'This project is personal' => 'Aquest projecte és privat',
    'Add' => 'Afegeix',
    'Start date' => 'Data d\'inici',
    'Time estimated' => 'Temps estimat',
    'There is nothing assigned to you.' => 'No tens res assignat.',
    'My tasks' => 'Les meves tasques',
    'Activity stream' => 'Fluxe d\'activitat',
    'Dashboard' => 'Panell',
    'Confirmation' => 'Confirmació',
    'Webhooks' => 'WebHooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Crear un comentari d\'un proveïdor extern',
    'Project management' => 'Gestió de projectes',
    'Columns' => 'Columnes',
    'Task' => 'Tasca',
    'Percentage' => 'Percentatge',
    'Number of tasks' => 'Nombre de tasques',
    'Task distribution' => 'Distribució de tasques',
    'Analytics' => 'Analítica',
    'Subtask' => 'Subtasca',
    'User repartition' => 'Repartiment d\'usuari',
    'Clone this project' => 'Clonar aquest projecte',
    'Column removed successfully.' => 'Columna eliminat correctament.',
    'Not enough data to show the graph.' => 'No hi ha dades suficients per mostrar el gràfic.',
    'Previous' => 'Anterior',
    'The id must be an integer' => 'L\'identificador ha de ser un nombre enter',
    'The project id must be an integer' => 'L\'identificador de projecte ha de ser un enter',
    'The status must be an integer' => 'L\'estat ha de ser un enter',
    'The subtask id is required' => 'Es requereix que l\'ID subtasca',
    'The subtask id must be an integer' => 'L\'identificador de subtasca ha de ser un enter',
    'The task id is required' => 'Es requereix que l\'ID de tasca',
    'The task id must be an integer' => 'L\'identificador de tasca ha de ser un enter',
    'The user id must be an integer' => 'L\'identificador d\'usuari ha de ser un nombre enter',
    'This value is required' => 'Aquest valor és necessari',
    'This value must be numeric' => 'Aquest valor ha de ser numèric',
    'Unable to create this task.' => 'No es pot crear aquesta tasca.',
    'Cumulative flow diagram' => 'Diagrama de flux acumulat',
    'Daily project summary' => 'Resum diari projecte',
    'Daily project summary export' => 'Exportació del resum diari del projecte',
    'Exports' => 'Exportacions',
    'This export contains the number of tasks per column grouped per day.' => 'Aquesta exportació conté el nombre de tasques per columna agrupada per dia.',
    'Active swimlanes' => 'Swimlanes actius',
    'Add a new swimlane' => 'Afegeix un nou swimlane',
    'Default swimlane' => 'Swimlane per defecte',
    'Do you really want to remove this swimlane: "%s"?' => 'Segur que vols eliminar la swimlane: "%s"',
    'Inactive swimlanes' => 'Swimlanes inactius',
    'Remove a swimlane' => 'Traieu un carril',
    'Swimlane modification for the project "%s"' => 'Modificació del swimlane pel projecte "%s"',
    'Swimlane removed successfully.' => 'Swimlane eliminat correctament.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane actualitzat correctament.',
    'Unable to remove this swimlane.' => 'No es pot eliminar aquest swimlane.',
    'Unable to update this swimlane.' => 'No es pot actualitzar aquest swimlane.',
    'Your swimlane has been created successfully.' => 'La seva swimlane s\'han creat amb èxit.',
    'Example: "Bug, Feature Request, Improvement"' => 'Exemple: "Bug, Comanda de funcions, Millora"',
    'Default categories for new projects (Comma-separated)' => 'Categories per defecte per a nous projectes (separats per comes)',
    'Integrations' => 'Integracions',
    'Integration with third-party services' => 'Integració amb els serveis de tercers',
    'Subtask Id' => 'ID de subtasca',
    'Subtasks' => 'Subtasques',
    'Subtasks Export' => 'Exportació de subtasques',
    'Task Title' => 'Títol de la tasca',
    'Untitled' => 'Sense títol',
    'Application default' => 'Per defecte de l\'aplicació',
    'Language:' => 'Llengua:',
    'Timezone:' => 'Zona horària:',
    'All columns' => 'Totes les columnes',
    'Next' => 'Pròxim',
    '#%d' => '#%d',
    'All swimlanes' => 'Tots swimlanes',
    'All colors' => 'Tots els colors',
    'Moved to column %s' => 'Traslladat a la columna %s',
    'User dashboard' => 'Tauler d\'usuari',
    'Allow only one subtask in progress at the same time for a user' => 'Permetre només una subtasca en curs al mateix temps per a un usuari',
    'Edit column "%s"' => 'Modifica la columna "%s"',
    'Select the new status of the subtask: "%s"' => 'Sel·lecciona el nou estat per la subtasca: "%s"',
    'Subtask timesheet' => 'Part d\'hores de subtasca',
    'There is nothing to show.' => 'Res per mostrar.',
    'Time Tracking' => 'Control d\'hores',
    'You already have one subtask in progress' => 'Ja tens una subtasca en curs',
    'Which parts of the project do you want to duplicate?' => 'Quines parts del projecte vols duplicar?',
    'Disallow login form' => 'No permetre formulari d\'accés',
    'Start' => 'Començar',
    'End' => 'Final',
    'Task age in days' => 'L\'edat de tasques en dies',
    'Days in this column' => 'Dies en aquesta columna',
    '%dd' => '%dd',
    'Add a new link' => 'Afegeix un nou enllaç',
    'Do you really want to remove this link: "%s"?' => 'Segur que vols eliminar aquest enllaç: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Segur que vols eliminar aquest enllaç amb la tasca #%d?',
    'Field required' => 'Camp requerit',
    'Link added successfully.' => 'Enllaç afegit correctament.',
    'Link updated successfully.' => 'Enllaç actualitzat correctament.',
    'Link removed successfully.' => 'Enllaç eliminat amb èxit.',
    'Link labels' => 'Etiquetes d\'enllaç',
    'Link modification' => 'Modificació d\'enllaç',
    'Opposite label' => 'Etiqueta oposada',
    'Remove a link' => 'Suprimir un enllaç',
    'The labels must be different' => 'Les etiquetes han de ser diferents',
    'There is no link.' => 'No hi ha cap relació.',
    'This label must be unique' => 'Aquest avís ha de ser únic',
    'Unable to create your link.' => 'No es pot crear l\'enllaç.',
    'Unable to update your link.' => 'No es pot actualitzar el seu enllaç.',
    'Unable to remove this link.' => 'No es pot eliminar aquest enllaç.',
    'relates to' => 'es refereix a',
    'blocks' => 'bloqueja',
    'is blocked by' => 'està bloquejada per',
    'duplicates' => 'duplica',
    'is duplicated by' => 'es duplica per',
    'is a child of' => 'és fill de',
    'is a parent of' => 'és pare de',
    'targets milestone' => 'objectiu de la fita',
    'is a milestone of' => 'és una fita de',
    'fixes' => 'corregeix',
    'is fixed by' => 'corregit per',
    'This task' => 'Aquesta tasca',
    '<1h' => '<1h',
    // '%dh' => '',
    'Expand tasks' => 'Amplia les tasques',
    'Collapse tasks' => 'Col·lapsa les tasques',
    'Expand/collapse tasks' => 'Amplia les tasques / col·lapsa',
    'Close dialog box' => 'Quadre de diàleg tancar',
    'Submit a form' => 'Envia un formulari',
    'Board view' => 'Mostra el tauler',
    'Keyboard shortcuts' => 'Dreceres de teclat',
    'Open board switcher' => 'Obre commutador de tauler',
    'Application' => 'Aplicació',
    'Compact view' => 'Vista compacta',
    'Horizontal scrolling' => 'Desplaçament horitzontal',
    'Compact/wide view' => 'Vista compacta / ample',
    'Currency' => 'Moneda',
    'Personal project' => 'Projecte privat',
    'AUD - Australian Dollar' => 'MXN - Dòlar australià',
    'CAD - Canadian Dollar' => 'CAD - Dòlar canadenc',
    'CHF - Swiss Francs' => 'CHF - Franc suís',
    'Custom Stylesheet' => 'Estil personalitzat',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Lliura britànica',
    'INR - Indian Rupee' => 'INR - Rupia índia',
    'JPY - Japanese Yen' => 'JPY - El ien japonès',
    'NZD - New Zealand Dollar' => 'NZD - Dòlar de Nova Zelanda',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => 'RSD - Dinar serbi',
    'CNY - Chinese Yuan' => 'CNY - Yuan xinès',
    'USD - US Dollar' => 'USD - El dòlar dels EUA',
    // 'VES - Venezuelan Bolívar' => '',
    'Destination column' => 'Columna de destinació',
    'Move the task to another column when assigned to a user' => 'Mou la tasca a una altra columna quan s\'assigna a un usuari',
    'Move the task to another column when assignee is cleared' => 'Mou la tasca a una altra columna quan s\'esborra assignat',
    'Source column' => 'Columna d\'origen',
    'Transitions' => 'Transicions',
    'Executer' => 'Executor',
    'Time spent in the column' => 'El temps emprat a la columna',
    'Task transitions' => 'transicions de tasques',
    'Task transitions export' => 'Tasca transicions d\'exportació',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Aquest informe conté tots els moviments de columna per a cada tasca amb la data, l\'usuari i el temps per a cada transició.',
    'Currency rates' => 'Monedes',
    'Rate' => 'Preu',
    'Change reference currency' => 'Moneda de canvi de referència',
    'Reference currency' => 'Moneda de referència',
    'The currency rate has been added successfully.' => 'El tipus de canvi s\'ha afegit amb èxit.',
    'Unable to add this currency rate.' => 'No es pot afegeix aquest tipus de moneda.',
    'Webhook URL' => 'URL web hook',
    '%s removed the assignee of the task %s' => '%s ha eliminat l\'assignat de la tasca %s',
    'Information' => 'Informació',
    'Check two factor authentication code' => 'Comprovar el codi d\'autenticació de dos factors',
    'The two factor authentication code is not valid.' => 'El codi d\'autenticació de dos factors no és vàlid.',
    'The two factor authentication code is valid.' => 'El codi d\'autenticació de dos factors és vàlid.',
    'Code' => 'Codi',
    'Two factor authentication' => 'Autenticació de dos factors',
    // 'This QR code contains the key URI: ' => '',
    'Check my code' => 'Comprovar el meu codi',
    // 'Secret key: ' => '',
    'Test your device' => 'Prova el teu dispositiu',
    'Assign a color when the task is moved to a specific column' => 'Assignar un color quan la tasca es mou a una columna específica',
    '%s via Kanboard' => '%s a través del Kanboard',
    'Burndown chart' => 'Burndown chart',
    'This chart show the task complexity over the time (Work Remaining).' => 'Aquesta gràfica mostra la dificultat de la tasca en el temps (Treball restant).',
    'Screenshot taken %s' => 'Imatge presa %s',
    'Add a screenshot' => 'Afegeix una captura de pantalla',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Prengui una captura de pantalla i premeu CTRL + V o ⌘ + V per enganxar aquí.',
    'Screenshot uploaded successfully.' => 'Captura carregat correctament.',
    'SEK - Swedish Krona' => 'SEK - Corona sueca',
    'Identifier' => 'Identificador',
    'Disable two factor authentication' => 'Desactiva l\'autenticació de dos factors',
    // 'Do you really want to disable the two factor authentication for this user: "%s"?' => '',
    'Edit link' => 'Edita enllaç',
    'Start to type task title...' => 'Comenceu a títol de la tasca de tipus ...',
    'A task cannot be linked to itself' => 'Una tasca no pot vincular-se a si mateix',
    'The exact same link already exists' => 'La mateixa relació exacta ja existeix',
    'Recurrent task is scheduled to be generated' => 'La tasca recurrent està programada per ser generada',
    'Score' => 'Puntuació',
    'The identifier must be unique' => 'L\'identificador ha de ser únic',
    // 'This linked task id doesn\'t exists' => '',
    'This value must be alphanumeric' => 'Aquest valor ha de ser alfanumèric',
    'Edit recurrence' => 'Edita recurrència',
    'Generate recurrent task' => 'Generar tasca recurrent',
    'Trigger to generate recurrent task' => 'Desencadenar per generar tasca recurrent',
    'Factor to calculate new due date' => 'Factor per calcular la nova data de venciment',
    'Timeframe to calculate new due date' => 'Marc de temps per calcular la nova data de venciment',
    'Base date to calculate new due date' => 'Data de referència per al càlcul de la nova data de venciment',
    'Action date' => 'data d\'acció',
    'Base date to calculate new due date: ' => 'Data base per a calcular nova data de venciment: ',
    'This task has created this child task: ' => 'Aquesta tasca ha creat aquesta tasca filla: ',
    'Day(s)' => 'Dia (Dies)',
    'Existing due date' => 'Data de venciment existent',
    // 'Factor to calculate new due date: ' => '',
    'Month(s)' => 'Mes (Mesos)',
    'This task has been created by: ' => 'Tasca creada per: ',
    'Recurrent task has been generated:' => 'La tasca recurrent s\'ha generat:',
    // 'Timeframe to calculate new due date: ' => '',
    // 'Trigger to generate recurrent task: ' => '',
    'When task is closed' => 'Quan la tasca està tancada',
    'When task is moved from first column' => 'Quan la tasca es mou de la primera columna',
    'When task is moved to last column' => 'Quan la tasca es mou a última columna',
    'Year(s)' => 'Any (s)',
    'Project settings' => 'Configuració del projecte',
    'Automatically update the start date' => 'Actualitzar automàticament la data d\'inici',
    'iCal feed' => 'Origen iCal',
    'Preferences' => 'Configuració',
    'Security' => 'Seguretat',
    'Two factor authentication disabled' => 'L\'autenticació de dos factors deshabilitat',
    'Two factor authentication enabled' => 'Autenticació de dos factors activada',
    'Unable to update this user.' => 'No es pot actualitzar aquest usuari.',
    'There is no user management for personal projects.' => 'No hi ha una gestió d\'usuaris per a projectes privats.',
    'User that will receive the email' => 'L\'usuari que rebrà el correu electrònic',
    'Email subject' => 'assumpte del correu electrònic',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Afegeix un registre comentari en moure la tasca entre les columnes',
    'Move the task to another column when the category is changed' => 'Mou la tasca a una altra columna quan es canvia la categoria',
    'Send a task by email to someone' => 'Envia una tasca per correu electrònic a algú',
    'Reopen a task' => 'Torneu a obrir una tasca',
    'Notification' => 'Notificació',
    '%s moved the task #%d to the first swimlane' => '%s van moure la tasca #%d per al primer swimlane',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s es va traslladar la tasca %s per al primer swimlane',
    // '%s moved the task %s to the swimlane "%s"' => '',
    'This report contains all subtasks information for the given date range.' => 'Aquest informe conté tota la informació subtasques per al període de temps.',
    'This report contains all tasks information for the given date range.' => 'Aquest informe conté tota la informació de tasques per al període de temps.',
    'Project activities for %s' => 'Les activitats del projecte per a %s',
    'view the board on Kanboard' => 'Veure el tauler en Kanboard',
    'The task has been moved to the first swimlane' => 'La tasca ha estat mogut a la primera swimlane',
    'The task has been moved to another swimlane:' => 'La tasca s\'han traslladat a un altre swimlane:',
    'New title: %s' => 'Nou títol: %s',
    'The task is not assigned anymore' => 'La tasca no s\'ha assignat més',
    'New assignee: %s' => 'Nova assignat:%s',
    'There is no category now' => 'No hi ha una categoria ara',
    'New category: %s' => 'Nova categoria:%s',
    'New color: %s' => 'Nou color: %s',
    'New complexity: %d' => 'Nova dificultat: %d',
    'The due date has been removed' => 'La data de venciment s\'han eliminat',
    'There is no description anymore' => 'No hi ha una descripció més',
    'Recurrence settings has been modified' => 'ajustos de recurrència s\'han modificat',
    // 'Time spent changed: %sh' => '',
    // 'Time estimated changed: %sh' => '',
    // 'The field "%s" has been updated' => '',
    'The description has been modified:' => 'La descripció s\'ha modificat:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Vols tancar la tasca "%s", així com totes les subtasques?',
    'I want to receive notifications for:' => 'Vull rebre notificacions per:',
    'All tasks' => 'totes les tasques',
    'Only for tasks assigned to me' => 'Només per a les tasques que se m\'ha s\'assignin',
    'Only for tasks created by me' => 'Només per a les tasques creades per mi',
    'Only for tasks created by me and tasks assigned to me' => 'Només per a tasques creades per mi i em assignin',
    // '%%Y-%%m-%%d' => '',
    'Total for all columns' => 'Total per a totes les columnes',
    'You need at least 2 days of data to show the chart.' => 'Es necessita com a mínim 2 dies de dades per mostrar el gràfic.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Atura el temporitzador',
    'Start timer' => 'Inicia el temporitzador',
    'My activity stream' => 'El meu fluxe d\'activitat',
    'Search tasks' => 'Cerca de tasques',
    'Reset filters' => 'Restableix filtres',
    'My tasks due tomorrow' => 'Les meves tasques per demà',
    'Tasks due today' => 'Tasques que vencen avui',
    'Tasks due tomorrow' => 'Tasques per demà',
    'Tasks due yesterday' => 'Tasques a causa ahir',
    'Closed tasks' => 'Tasques tancades',
    'Open tasks' => 'Tasques obertes',
    'Not assigned' => 'No assignat',
    'View advanced search syntax' => 'Veure sintaxi de cerca avançada',
    'Overview' => 'Visió de conjunt',
    'Board/Calendar/List view' => 'Tauler / Calendari / Vista de llista',
    'Switch to the board view' => 'Canviar a la vista de tauler',
    'Switch to the list view' => 'Canviar a la vista de llista',
    'Go to the search/filter box' => 'Anar al quadre de cerca / filtre',
    'There is no activity yet.' => 'No hi ha cap activitat encara.',
    'No tasks found.' => 'No s\'han trobat tasques.',
    'Keyboard shortcut: "%s"' => 'Drecera de teclat: "%s"',
    'List' => 'Llista',
    'Filter' => 'Filtre',
    'Advanced search' => 'Cerca avançada',
    'Example of query: ' => 'Exemple de consulta: ',
    'Search by project: ' => 'Cerca per projecte: ',
    'Search by column: ' => 'Cerca per columna: ',
    'Search by assignee: ' => 'Cerca per assignat: ',
    'Search by color: ' => 'Cerca per color: ',
    'Search by category: ' => 'Cerca per categoria: ',
    'Search by description: ' => 'Cerca per descripció: ',
    'Search by due date: ' => 'Cerca per data de venciment: ',
    'Average time spent in each column' => 'Temps mitjà de permanència en cada columna',
    'Average time spent' => 'Temps mitjà de permanència',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Aquest gràfic mostra el temps mitjà de permanència en cada columna per a les últimes %d tasques.',
    'Average Lead and Cycle time' => 'El plom i la mitjana del temps de cicle',
    'Average lead time: ' => 'Mitjana de temps de lliurament: ',
    'Average cycle time: ' => 'Mitjana de temps de cicle: ',
    'Cycle Time' => 'Temps de cicle',
    'Lead Time' => 'Temps de lliurament',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Aquesta taula mostra la mitjana de plom i el temps de cicle per a les últimes tasques %d respecte al temps.',
    'Average time into each column' => 'Temps mitjà en cada columna',
    'Lead and cycle time' => 'Temps de lliurament i cicle',
    'Lead time: ' => 'Temps de lliurament: ',
    'Cycle time: ' => 'Temps del cicle: ',
    'Time spent in each column' => 'El temps invertit en cada columna',
    'The lead time is the duration between the task creation and the completion.' => 'El termini d\'execució és la durada entre la creació de la tasca i la finalització.',
    'The cycle time is the duration between the start date and the completion.' => 'El temps de cicle és la durada entre la data d\'inici i la finalització.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Si la tasca no està tancat el moment actual s\'utilitza en lloc de la data de finalització.',
    'Set the start date automatically' => 'S\'ajusta automàticament la data d\'inici',
    'Edit Authentication' => 'Edita autenticació',
    'Remote user' => 'Usuari remot',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Els usuaris remots no emmagatzemen la contrasenya a la base de dades Kanboard, exemples: els comptes LDAP, Google i Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Si marca la casella "No permetre formulari d\'accés", s\'ignoraran les credencials introduïdes al formulari d\'inici de sessió.',
    'Default task color' => 'Color per defecte de les tasques',
    'This feature does not work with all browsers.' => 'Aquesta característica no funciona amb tots els navegadors.',
    'There is no destination project available.' => 'No hi ha cap projecte de destinació disponibles.',
    'Trigger automatically subtask time tracking' => 'Desencadenar automàticament control d\'hores de subtasca',
    'Include closed tasks in the cumulative flow diagram' => 'Incloure tasques tancades en el diagrama de flux acumulat',
    'Current swimlane: %s' => 'Swimlane actual: %s',
    'Current column: %s' => 'Columna actual: %s',
    'Current category: %s' => 'Categoria actual: %s',
    'no category' => 'cap categoria',
    'Current assignee: %s' => 'Assignat actual: %s',
    'not assigned' => 'no assignat',
    'Author:' => 'Autor:',
    'contributors' => 'contribuents',
    'License:' => 'Llicència:',
    'License' => 'Llicència',
    'Enter the text below' => 'Introduïu el text a continuació',
    'Start date:' => 'Data d\'inici:',
    'Due date:' => 'Data de venciment:',
    'People who are project managers' => 'Les persones que són caps de projecte',
    'People who are project members' => 'Les persones que són membres del projecte',
    'NOK - Norwegian Krone' => 'NOK - Corona noruega',
    'Show this column' => 'Mostra aquesta columna',
    'Hide this column' => 'Amaga aquesta columna',
    'End date' => 'Data de finalització',
    'Users overview' => 'Visió general dels usuaris',
    'Members' => 'Membres',
    'Shared project' => 'Projecte compartit',
    'Project managers' => 'Els gerents de projecte',
    'Projects list' => 'Llista de projectes',
    'End date:' => 'Data de finalització:',
    'Change task color when using a specific task link' => 'Canviar de color quan la tasca utilitzant un enllaç tasca específica',
    'Task link creation or modification' => 'La creació o modificació de l\'enllaç de tasques',
    'Milestone' => 'Fita',
    'Reset the search/filter box' => 'Restablir el quadre de cerca / filtre',
    'Documentation' => 'Documentació',
    'Author' => 'Autor',
    'Version' => 'Versió',
    'Plugins' => 'Connectors',
    'There is no plugin loaded.' => 'No hi ha cap complement carregat.',
    'My notifications' => 'Les meves notificacions',
    'Custom filters' => 'Filtres personalitzats',
    'Your custom filter has been created successfully.' => 'El seu filtre a mida s\'han creat amb èxit.',
    'Unable to create your custom filter.' => 'No es pot crear el filtre personalitzat.',
    'Custom filter removed successfully.' => 'Filtre a mida eliminat correctament.',
    'Unable to remove this custom filter.' => 'No es pot eliminar aquest filtre personalitzat.',
    'Edit custom filter' => 'Edita filtre a mida',
    'Your custom filter has been updated successfully.' => 'El seu filtre a mida s\'han actualitzat correctament.',
    'Unable to update custom filter.' => 'No es pot actualitzar filtre a mida.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nou adjunt a la tasca #%d: %s',
    'New comment on task #%d' => 'Nou comentari a la tasca #%d',
    'Comment updated on task #%d' => 'Comentari actualitzat a la tasca #%d',
    'New subtask on task #%d' => 'Nova subtasca a la tasca #%d',
    'Subtask updated on task #%d' => 'Subtasca s\'actualitza a la tasca #%d',
    'New task #%d: %s' => 'Nova tasca #%d: %s',
    'Task updated #%d' => 'Tasca actualitzada #%d',
    'Task #%d closed' => 'Tasca #%d tancada',
    'Task #%d opened' => 'Tasca #%d obrir',
    'Column changed for task #%d' => 'Columna canviada per la tasca #%d',
    'New position for task #%d' => 'Nova posició per la tasca #%d',
    'Swimlane changed for task #%d' => 'El swimlane va canviat per  la tasca #%d',
    'Assignee changed on task #%d' => 'L\'assignat va canviar a la tasca #%d',
    '%d overdue tasks' => '%d tasques endarrerides',
    'Task #%d is overdue' => 'La tasca #%d està vençuda',
    'No notification.' => 'Sense notificacions.',
    'Mark all as read' => 'Marca totes com llegides',
    'Mark as read' => 'Marca com llegida',
    'Total number of tasks in this column across all swimlanes' => 'Nombre total de tasques en aquesta columna a través de tots swimlanes',
    'Collapse swimlane' => 'Col·lapsa swimlane',
    'Expand swimlane' => 'Ampliar swimlane',
    'Add a new filter' => 'Afegeix un nou filtre',
    'Share with all project members' => 'Compartir amb tots els membres del projecte',
    'Shared' => 'Compartit',
    'Owner' => 'Propietari',
    'Unread notifications' => 'Notificacions no llegides',
    'Notification methods:' => 'Els mètodes de notificació:',
    'Unable to read your file' => 'No es pot llegir el fitxer',
    '%d task(s) have been imported successfully.' => '%d tasca(s) s\'han importat correctament.',
    'Nothing has been imported!' => 'Res s\'han importat!',
    'Import users from CSV file' => 'Importa usuaris des d\'arxiu CSV',
    '%d user(s) have been imported successfully.' => '%d usuari(s) s\'han importat correctament.',
    'Comma' => 'Coma',
    'Semi-colon' => 'Punt i coma',
    'Tab' => 'Llengüeta',
    'Vertical bar' => 'Barra vertical',
    'Double Quote' => 'Cometes dobles',
    'Single Quote' => 'Cometes simples',
    '%s attached a file to the task #%d' => '%s ha adjuntat un arxiu a la tasca #%d',
    'There is no column or swimlane activated in your project!' => 'No hi ha cap columna o swimlane activat en el seu projecte!',
    'Append filter (instead of replacement)' => 'Annexar filtre (en lloc de reemplaçament)',
    'Append/Replace' => 'Annexar / Reemplaçar',
    'Append' => 'Annexar',
    'Replace' => 'Reemplaçar',
    'Import' => 'Importació',
    'Change sorting' => 'Canvia la ordenació',
    'Tasks Importation' => 'Importació de tasques',
    'Delimiter' => 'Delimitador',
    'Enclosure' => 'Recinte',
    'CSV File' => 'Fitxer CSV',
    'Instructions' => 'Instruccions',
    'Your file must use the predefined CSV format' => 'El seu arxiu ha d\'utilitzar el format CSV predefinit',
    'Your file must be encoded in UTF-8' => 'El seu arxiu ha d\'estar codificat en UTF-8',
    'The first row must be the header' => 'La primera fila ha de ser la capçalera',
    'Duplicates are not verified for you' => 'Els duplicats no es verifiquen per a vostè',
    'The due date must use the ISO format: YYYY-MM-DD' => 'La data de venciment ha d\'utilitzar el format ISO: AAAA-MM-DD',
    'Download CSV template' => 'Descarregar plantilla CSV',
    'No external integration registered.' => 'No es va registrar la integració externa.',
    'Duplicates are not imported' => 'Els duplicats no s\'importen',
    'Usernames must be lowercase and unique' => 'Els noms d\'usuari han d\'estar en minúscules i únic',
    'Passwords will be encrypted if present' => 'Les contrasenyes es xifraran si està present',
    '%s attached a new file to the task %s' => '%s adjunta un arxiu nou a la tasca %s',
    'Link type' => 'Tipus d\'enllaç',
    'Assign automatically a category based on a link' => 'Assignar automàticament una categoria basada en un enllaç',
    'BAM - Konvertible Mark' => 'BAM - Konvertible Mark',
    'Assignee Username' => 'Nom d\'usuari assignat',
    'Assignee Name' => 'Nom assignat',
    'Groups' => 'Grups',
    'Members of %s' => 'Els membres de %s',
    'New group' => 'Nou grup',
    'Group created successfully.' => 'Grup creat correctament.',
    'Unable to create your group.' => 'No es pot crear el grup.',
    'Edit group' => 'Edita grup',
    'Group updated successfully.' => 'Grup actualitzat correctament.',
    'Unable to update your group.' => 'No es pot actualitzar el seu grup.',
    // 'Add group member to "%s"' => '',
    'Group member added successfully.' => 'Membre del grup afegit correctament.',
    'Unable to add group member.' => 'No es pot afegeix membre del grup.',
    // 'Remove user from group "%s"' => '',
    'User removed successfully from this group.' => 'Usuari eliminat amb èxit d\'aquest grup.',
    'Unable to remove this user from the group.' => 'No es pot eliminar aquest usuari del grup.',
    'Remove group' => 'Elimina el grup',
    'Group removed successfully.' => 'Grup eliminat correctament.',
    'Unable to remove this group.' => 'No es pot eliminar aquest grup.',
    'Project Permissions' => 'Permisos de projectes',
    'Manager' => 'Gerent',
    'Project Manager' => 'Gerent de projectes',
    'Project Member' => 'Membres del projecte',
    'Project Viewer' => 'Visor de projectes',
    'Your account is locked for %d minutes' => 'El seu compte està bloquejada per %d minuts',
    'Invalid captcha' => 'codi d\'imatge no vàlida',
    'The name must be unique' => 'El nom ha de ser únic',
    'View all groups' => 'Veure tots els grups',
    'There is no user available.' => 'No hi ha cap usuari disponible.',
    // 'Do you really want to remove the user "%s" from the group "%s"?' => '',
    'There is no group.' => 'No hi ha cap grup.',
    'Add group member' => 'Afegeix membre del grup',
    // 'Do you really want to remove this group: "%s"?' => '',
    'There is no user in this group.' => 'No hi ha cap usuari en aquest grup.',
    'Permissions' => 'Permisos',
    'Allowed Users' => 'Els usuaris autoritzats',
    'No specific user has been allowed.' => 'Cap usuari s\'hagi establert.',
    'Role' => 'Rol',
    'Enter user name...' => 'Introdueix el nom d\'usuari ...',
    'Allowed Groups' => 'Grups permesos',
    'No group has been allowed.' => 'Cap grup s\'hagi establert.',
    'Group' => 'Grup',
    'Group Name' => 'Nom del grup',
    'Enter group name...' => 'Introduïu el nom del grup ...',
    'Role:' => 'Rol:',
    'Project members' => 'Els membres del projecte',
    '%s mentioned you in the task #%d' => '%s t\'ha esmentat a la tasca #%d',
    '%s mentioned you in a comment on the task #%d' => '%s t\'ha mencionat en un comentari a la tasca #%d',
    'You were mentioned in the task #%d' => 'Se t\'ha esmentat a la tasca #%d',
    'You were mentioned in a comment on the task #%d' => 'Se t\'ha mencionat en un comentari sobre la tasca #%d',
    // 'Estimated hours: ' => '',
    // 'Actual hours: ' => '',
    'Hours Spent' => 'Les hores invertides',
    'Hours Estimated' => 'hores estimat',
    'Estimated Time' => 'Temps estimat',
    'Actual Time' => 'temps real',
    'Estimated vs actual time' => 'Estimat en funció del temps real',
    'RUB - Russian Ruble' => 'RUB - Russia rus',
    'Assign the task to the person who does the action when the column is changed' => 'Assignar la tasca a la persona que fa l\'acció quan es canvia la columna',
    'Close a task in a specific column' => 'Tancar una tasca en una columna específica',
    'Time-based One-time Password Algorithm' => 'Algoritme de contrasenya basat en el temps d\'una sola vegada',
    // 'Two-Factor Provider: ' => '',
    'Disable two-factor authentication' => 'Deshabilita l\'autenticació de dos factors',
    'Enable two-factor authentication' => 'Habilitar l\'autenticació de dos factors',
    'There is no integration registered at the moment.' => 'No hi ha integració registrada en el moment.',
    'Password Reset for Kanboard' => 'Restableix contrasenya per Kanboard',
    'Forgot password?' => 'Has oblidat la contrasenya?',
    'Enable "Forget Password"' => 'Habilita "he oblidat la contrasenya"',
    'Password Reset' => 'Restablir contrasenya',
    'New password' => 'Nova contrasenya',
    'Change Password' => 'Canvia la contrasenya',
    'To reset your password click on this link:' => 'Per restablir la contrasenya, feu clic en aquest enllaç:',
    'Last Password Reset' => 'Darrer restabliment de contrasenya',
    'The password has never been reinitialized.' => 'La contrasenya mai ha estat reiniciada.',
    'Creation' => 'Creació',
    'Expiration' => 'Caducitat',
    'Password reset history' => 'Històric de restabliment de contrasenya',
    // 'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '',
    'Do you really want to close all tasks of this column?' => 'Vols tancar totes les tasques d\'aquesta columna?',
    // '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '',
    'Close all tasks in this column and this swimlane' => 'Tanqueu totes les tasques d\'aquesta columna',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'No s\'ha registrat plugin d\'un mètode de notificació del projecte. Encara es pot configurar les notificacions individuals en el seu perfil d\'usuari.',
    'My dashboard' => 'El meu tauler',
    'My profile' => 'El meu perfil',
    'Project owner: ' => 'Propietari del projecte: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'L\'identificador de projecte és opcional i ha de ser alfanumèric, exemple: MYPROJECT.',
    'Project owner' => 'Propietari del projecte',
    'Personal projects do not have users and groups management.' => 'projectes privats no tenen els usuaris i grups de gestió.',
    'There is no project member.' => 'No hi ha cap membre del projecte.',
    'Priority' => 'Prioritat',
    'Task priority' => 'Prioritat de la tasca',
    'General' => 'General',
    'Dates' => 'Dates',
    'Default priority' => 'Prioritat per defecte',
    'Lowest priority' => 'La prioritat més baixa',
    'Highest priority' => 'La prioritat més alta',
    'Close a task when there is no activity' => 'Tancar una tasca quan no hi ha activitat',
    'Duration in days' => 'Durada en dies',
    'Send email when there is no activity on a task' => 'Envia correu electrònic quan no hi ha activitat en una tasca',
    'Unable to fetch link information.' => 'No és possible obtenir informació d\'enllaç.',
    'Daily background job for tasks' => 'Feina en segon pla diaria per a les tasques',
    'Auto' => 'Auto',
    'Related' => 'Relacionat',
    'Attachment' => 'Adjunt',
    'Title not found' => 'Títol no trobat',
    'Web Link' => 'Enllaç web',
    'External links' => 'Enllaços externs',
    'Add external link' => 'Afegeix un enllaç extern',
    'Type' => 'Tipus',
    'Dependency' => 'Dependència',
    'Add internal link' => 'Afegeix un enllaç intern',
    'Add a new external link' => 'Afegeix un nou enllaç extern',
    'Edit external link' => 'Edita enllaç extern',
    'External link' => 'URL',
    'Copy and paste your link here...' => 'Copia i enganxa l\'enllaç aquí ...',
    'URL' => 'URL',
    'Internal links' => 'Els enllaços interns',
    'Assign to me' => 'Assignar a mi',
    'Me' => 'jo',
    'Do not duplicate anything' => 'No dupliquis res',
    'Projects management' => 'Gestió de projectes',
    'Users management' => 'Gestió d\'usuaris',
    'Groups management' => 'Gestió de grups',
    'Create from another project' => 'Crea a partir d\'un altre projecte',
    'open' => 'obert',
    'closed' => 'tancat',
    'Priority:' => 'Prioritat:',
    'Reference:' => 'Referència:',
    'Complexity:' => 'Dificultat:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Columna:',
    'Position:' => 'Posició:',
    'Creator:' => 'Creador:',
    'Time estimated:' => 'Temps estimat:',
    '%s hours' => '%s hora',
    'Time spent:' => 'El temps passat:',
    'Created:' => 'Creat:',
    'Modified:' => 'Modificat:',
    'Completed:' => 'Completat:',
    'Started:' => 'Començat:',
    'Moved:' => 'Mogut:',
    'Task #%d' => 'Tasca #%d',
    'Time format' => 'Format d\'hora',
    'Start date: ' => 'Data d\'inici: ',
    'End date: ' => 'Data de fi: ',
    'New due date: ' => 'Nova data de venciment: ',
    'Start date changed: ' => 'Data d\'inici canviada: ',
    'Disable personal projects' => 'Desactivar els projectes privats',
    // 'Do you really want to remove this custom filter: "%s"?' => '',
    'Remove a custom filter' => 'Treure un filtre a mida',
    'User activated successfully.' => 'L\'usuari ha activat correctament.',
    'Unable to enable this user.' => 'No és possible permetre que aquest usuari.',
    'User disabled successfully.' => 'L\'usuari deshabilitat amb èxit.',
    'Unable to disable this user.' => 'No és possible desactivar aquest usuari.',
    'All files have been uploaded successfully.' => 'Tots els arxius s\'hagin carregat correctament.',
    // 'The maximum allowed file size is %sB.' => '',
    'Drag and drop your files here' => 'Arrossegar i deixar anar els arxius aquí',
    'choose files' => 'triar els arxius',
    'View profile' => 'Veure el perfil',
    'Two Factor' => 'dos factors',
    'Disable user' => 'desactivar usuari',
    // 'Do you really want to disable this user: "%s"?' => '',
    'Enable user' => 'Permetre a l\'usuari',
    // 'Do you really want to enable this user: "%s"?' => '',
    'Download' => 'Descarregar',
    'Uploaded: %s' => 'Pujat: %s',
    'Size: %s' => 'Mida: %s',
    'Uploaded by %s' => 'Pujada per %s',
    'Filename' => 'Nom de l\'arxiu',
    'Size' => 'Mida',
    'Column created successfully.' => 'Columna creat correctament.',
    'Another column with the same name exists in the project' => 'Una altra columna amb el mateix nom existeix en el projecte',
    'Default filters' => 'filtres predeterminats',
    // 'Your board doesn\'t have any columns!' => '',
    'Change column position' => 'Canvi de posició de columna',
    'Switch to the project overview' => 'Canviar a la visió general del projecte',
    'User filters' => 'Els filtres d\'usuari',
    'Category filters' => 'filtres de categories',
    'Upload a file' => 'Pujar un arxiu',
    'View file' => 'Veure arxiu',
    'Last activity' => 'Última activitat',
    'Change subtask position' => 'Subtasca posició de canvi',
    'This value must be greater than %d' => 'Aquest valor ha de ser més gran que %d',
    'Another swimlane with the same name exists in the project' => 'Una altra swimlane amb el mateix nom existeix en el projecte',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Exemple: https://example.kanboard.org/ (utilitzat per generar URL absoluta)',
    'Actions duplicated successfully.' => 'Accions dupliquen amb èxit.',
    'Unable to duplicate actions.' => 'No s\'ha pogut duplicar accions.',
    'Add a new action' => 'Afegeix una nova acció',
    'Import from another project' => 'Importa d\'un altre projecte',
    'There is no action at the moment.' => 'No hi ha cap acció en aquest moment.',
    'Import actions from another project' => 'accions d\'importació d\'un altre projecte',
    'There is no available project.' => 'No hi ha un projecte disponible.',
    'Local File' => 'Fitxer local',
    'Configuration' => 'Configuració',
    'PHP version:' => 'Versió de PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versió del sistema operatiu:',
    'Database version:' => 'Versió de la base de dades:',
    'Browser:' => 'Navegador:',
    'Task view' => 'Vista de tasques',
    'Edit task' => 'Edició de tasques',
    'Edit description' => 'Modifica la descripció',
    'New internal link' => 'Nou enllaç intern',
    'Display list of keyboard shortcuts' => 'Visualització de la llista de dreceres de teclat',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Puja la imatge meu avatar',
    'Remove my image' => 'Traieu la meva imatge',
    'The OAuth2 state parameter is invalid' => 'El paràmetre d\'estat OAuth2 no és vàlid',
    'User not found.' => 'Usuari no trobat.',
    'Search in activity stream' => 'Buscar en el Tràfic d\'activitat',
    'My activities' => 'Les meves activitats',
    'Activity until yesterday' => 'Activitat fins ahir',
    'Activity until today' => 'Activitat fins avui',
    // 'Search by creator: ' => '',
    // 'Search by creation date: ' => '',
    // 'Search by task status: ' => '',
    // 'Search by task title: ' => '',
    'Activity stream search' => 'Cerca al fluxe d\'activitat',
    // 'Projects where "%s" is manager' => '',
    // 'Projects where "%s" is member' => '',
    // 'Open tasks assigned to "%s"' => '',
    // 'Closed tasks assigned to "%s"' => '',
    'Assign automatically a color based on a priority' => 'Assignar automàticament un color basat en una prioritat',
    // 'Overdue tasks for the project(s) "%s"' => '',
    'Upload files' => 'Pujar arxius',
    'Installed Plugins' => 'Els connectors instal·lats',
    'Plugin Directory' => 'Directori de complements',
    'Plugin installed successfully.' => 'Plug-in instal·lat correctament.',
    'Plugin updated successfully.' => 'Plugin actualitzat correctament.',
    'Plugin removed successfully.' => 'Plugin eliminat correctament.',
    'Subtask converted to task successfully.' => 'Subtasca converteix en tasca amb èxit.',
    'Unable to convert the subtask.' => 'No es pot convertir la subtasca.',
    'Unable to extract plugin archive.' => 'No es pot extreure arxiu connector.',
    'Plugin not found.' => 'Plugin no trobat.',
    // 'You don\'t have the permission to remove this plugin.' => '',
    'Unable to download plugin archive.' => 'No es pot descarregar arxiu connector.',
    'Unable to write temporary file for plugin.' => 'No es pot escriure el fitxer temporal per al connector.',
    'Unable to open plugin archive.' => 'No es pot obrir arxiu de plugin.',
    'There is no file in the plugin archive.' => 'No hi ha cap arxiu a l\'arxiu connector.',
    'Create tasks in bulk' => 'Crear tasques a granel',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'La instància Kanboard no està configurat per a instal·lar plugins des de la interfície d\'usuari.',
    'There is no plugin available.' => 'No hi ha cap complement disponible.',
    'Install' => 'Instal·la',
    'Update' => 'Actualitza',
    'Up to date' => 'Actualitzat',
    'Not available' => 'No disponible',
    'Remove plugin' => 'Eliminar connector',
    // 'Do you really want to remove this plugin: "%s"?' => '',
    'Uninstall' => 'Suprimeix',
    'Listing' => 'Llistat',
    'Metadata' => 'Metadades',
    'Manage projects' => 'Gestió de projectes',
    'Convert to task' => 'Convertir la tasca',
    'Convert sub-task to task' => 'Converteix sub-tasca a una altra',
    'Do you really want to convert this sub-task to a task?' => 'Vols convertir aquesta sub-tasca a una tasca?',
    'My task title' => 'Títol de la tasca',
    'Enter one task by line.' => 'Introduïu una tasca per línia.',
    'Number of failed login:' => 'Nombre d\'inici de sessió fallit:',
    'Account locked until:' => 'Compte bloquejada fins que:',
    'Email settings' => 'Configuració de correu electrònic',
    'Email sender address' => 'Adreça de correu electrònic del remitent',
    'Email transport' => 'Transport de correu electrònic',
    'Webhook token' => 'Símbol web hook',
    'Project tags management' => 'Gestió de projectes etiquetes',
    'Tag created successfully.' => 'Tag creat correctament.',
    'Unable to create this tag.' => 'No es pot crear aquesta etiqueta.',
    'Tag updated successfully.' => 'Tag actualitzat correctament.',
    'Unable to update this tag.' => 'No es pot actualitzar aquesta etiqueta.',
    'Tag removed successfully.' => 'Tag eliminat correctament.',
    'Unable to remove this tag.' => 'No es pot eliminar aquesta etiqueta.',
    'Global tags management' => 'Gestió global d\'etiquetes',
    'Tags' => 'Etiquetes',
    'Tags management' => 'Gestió d\'etiquetes',
    'Add new tag' => 'Afegeix nova etiqueta',
    'Edit a tag' => 'Edita una etiqueta',
    'Project tags' => 'Variables del projecte',
    'There is no specific tag for this project at the moment.' => 'No hi ha una etiqueta específica per a aquest projecte en aquest moment.',
    'Tag' => 'Etiqueta',
    'Remove a tag' => 'Elimina una etiqueta',
    // 'Do you really want to remove this tag: "%s"?' => '',
    'Global tags' => 'etiquetes globals',
    'There is no global tag at the moment.' => 'No hi ha cap variable global en el moment.',
    'This field cannot be empty' => 'Aquest camp no pot estar buit',
    'Close a task when there is no activity in a specific column' => 'Tancar una tasca quan no hi ha activitat en una columna específica',
    '%s removed a subtask for the task #%d' => '%s extret una subtasca per a la tasca #%d',
    '%s removed a comment on the task #%d' => '%s remogut un comentari a la tasca #%d',
    'Comment removed on task #%d' => 'Comentari eliminat a la tasca #%d',
    'Subtask removed on task #%d' => 'Subtasca eliminat a la tasca #%d',
    'Hide tasks in this column in the dashboard' => 'Amaga tasques en aquesta columna al tauler d\'instruments',
    '%s removed a comment on the task %s' => '%s remogut un comentari a la tasca %s',
    '%s removed a subtask for the task %s' => '%s extret una subtasca per a la tasca %s',
    'Comment removed' => 'Es va eliminar el comentari',
    'Subtask removed' => 'subtasca retira',
    '%s set a new internal link for the task #%d' => '%s va establir un nou enllaç intern per a la tasca #%d',
    '%s removed an internal link for the task #%d' => '%s eliminat un enllaç intern per a la tasca #%d',
    'A new internal link for the task #%d has been defined' => 'Un nou enllaç intern per a la tasca #%d s\'han definit',
    'Internal link removed for the task #%d' => 'Enllaç intern eliminat la tasca #%d',
    '%s set a new internal link for the task %s' => '%s va establir un nou enllaç intern per a la tasca %s',
    '%s removed an internal link for the task %s' => '%s eliminat un enllaç intern per a la tasca %s',
    'Automatically set the due date on task creation' => 'S\'ajusta automàticament la data de venciment a la creació de tasques',
    'Move the task to another column when closed' => 'Mou la tasca a una altra columna quan es tanca',
    'Move the task to another column when not moved during a given period' => 'Mou la tasca a una altra columna quan no es va moure durant un període determinat',
    'Dashboard for %s' => 'Tauler de %s',
    'Tasks overview for %s' => 'Resum de tasques de %s',
    'Subtasks overview for %s' => 'Visió general de subtasques de %s',
    'Projects overview for %s' => 'Visió general del projecte de %s',
    'Activity stream for %s' => 'Fluxe d\'activitat per a %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Assignar un color quan la tasca es mou a un carril específic',
    'Assign a priority when the task is moved to a specific swimlane' => 'Assignar una prioritat quan la tasca es mou a un carril específic',
    'User unlocked successfully.' => 'Usuari desbloquejat amb èxit.',
    'Unable to unlock the user.' => 'No és possible desbloquejar l\'usuari.',
    'Move a task to another swimlane' => 'Mou una tasca a una altra swimlane',
    'Creator Name' => 'nom creador',
    'Time spent and estimated' => 'El temps dedicat i estima',
    'Move position' => 'Mou la posició',
    'Move task to another position on the board' => 'Mou tasca a una altra posició al tauler',
    'Insert before this task' => 'Insereix abans aquesta tasca',
    'Insert after this task' => 'Inserir, després d\'aquesta tasca',
    'Unlock this user' => 'Desbloquejar aquest usuari',
    'Custom Project Roles' => 'Rols d\'encàrrec del projecte',
    'Add a new custom role' => 'Afegeix un nou rol',
    // 'Restrictions for the role "%s"' => '',
    'Add a new project restriction' => 'Afegeix una nova restricció projecte',
    'Add a new drag and drop restriction' => 'Afegeix un nou arrossegar i deixar anar restricció',
    'Add a new column restriction' => 'Afegeix una nova restricció de columna',
    'Edit this role' => 'Edita aquest rol',
    'Remove this role' => 'Elimina aquest rol',
    'There is no restriction for this role.' => 'No hi ha cap restricció per a aquest rol.',
    'Only moving task between those columns is permitted' => 'Només es mou tasques entre aquestes columnes es permet',
    'Close a task in a specific column when not moved during a given period' => 'Tancar una tasca en una columna específica quan no es va moure durant un període determinat',
    'Edit columns' => 'Edita columnes',
    'The column restriction has been created successfully.' => 'La restricció de la columna s\'ha creat correctament.',
    'Unable to create this column restriction.' => 'No es pot crear aquesta restricció columna.',
    'Column restriction removed successfully.' => 'restricció Columna eliminat correctament.',
    'Unable to remove this restriction.' => 'No es pot eliminar aquesta restricció.',
    'Your custom project role has been created successfully.' => 'El seu rol projecte personalitzat s\'ha creat correctament.',
    'Unable to create custom project role.' => 'No es pot crear el rol de projecte personalitzat.',
    'Your custom project role has been updated successfully.' => 'El seu rol projecte personalitzat s\'ha actualitzat correctament.',
    'Unable to update custom project role.' => 'No es pot actualitzar rol projecte personalitzat.',
    'Custom project role removed successfully.' => 'rol projecte personalitzat eliminat correctament.',
    'Unable to remove this project role.' => 'No es pot treure aquest rol projecte.',
    'The project restriction has been created successfully.' => 'La restricció projecte ha estat creat amb èxit.',
    'Unable to create this project restriction.' => 'No es pot crear aquesta restricció projecte.',
    'Project restriction removed successfully.' => 'Projecte restricció eliminat correctament.',
    'You cannot create tasks in this column.' => 'No es poden crear tasques en aquesta columna.',
    'Task creation is permitted for this column' => 'Es permet la creació de tasques per a aquesta columna',
    'Closing or opening a task is permitted for this column' => 'Tancant o obrint una tasca està permesa per a aquesta columna',
    'Task creation is blocked for this column' => 'creació de la tasca està bloquejat per a aquesta columna',
    'Closing or opening a task is blocked for this column' => 'Tancant o obrint una tasca està bloquejat per a aquesta columna',
    'Task creation is not permitted' => 'No es permet la creació de tasques',
    'Closing or opening a task is not permitted' => 'No es permet tancar o obrir una tasca',
    // 'New drag and drop restriction for the role "%s"' => '',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Les persones que pertanyen a aquest rol seran capaços de moure les tasques només entre la font i la columna de destinació.',
    'Remove a column restriction' => 'Eliminar una restricció columna',
    // 'Do you really want to remove this column restriction: "%s" to "%s"?' => '',
    // 'New column restriction for the role "%s"' => '',
    'Rule' => 'regla',
    'Do you really want to remove this column restriction?' => 'Vols eliminar aquest criteri de la columna?',
    'Custom roles' => 'Rols personalitzats',
    'New custom project role' => 'Nou rol projecte personalitzat',
    'Edit custom project role' => 'Edita rol projecte personalitzat',
    'Remove a custom role' => 'Eliminar una funció personalitzada',
    // 'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '',
    'There is no custom role for this project.' => 'No hi ha una funció personalitzada per a aquest projecte.',
    // 'New project restriction for the role "%s"' => '',
    'Restriction' => 'Restricció',
    'Remove a project restriction' => 'Eliminar una restricció projecte',
    // 'Do you really want to remove this project restriction: "%s"?' => '',
    'Duplicate to multiple projects' => 'Duplica a múltiples projectes',
    'This field is required' => 'Aquest camp és obligatori',
    'Moving a task is not permitted' => 'No està permès moure una tasca',
    'This value must be in the range %d to %d' => 'Aquest valor ha d\'estar en el rang %d a %d',
    'You are not allowed to move this task.' => 'No se li permet moure a aquesta tasca.',
    'API User Access' => 'L\'accés d\'usuari d\'API',
    'Preview' => 'Vista prèvia',
    'Write' => 'escriure',
    'Write your text in Markdown' => 'Escriure el text en Markdown',
    'No personal API access token registered.' => 'Sense accés a l\'API personals símbol registrat.',
    // 'Your personal API access token is "%s"' => '',
    'Remove your token' => 'Traieu el testimoni',
    'Generate a new token' => 'Generar un nou token',
    // 'Showing %d-%d of %d' => '',
    'Outgoing Emails' => 'Els correus electrònics sortints',
    'Add or change currency rate' => 'Afegeix o canviar el valor de moneda',
    'Reference currency: %s' => 'moneda de referència: %s',
    'Add custom filters' => 'Afegeix filtres personalitzats',
    'Export' => 'exportació',
    'Add link label' => 'Afegeix etiqueta d\'enllaç',
    'Incompatible Plugins' => 'Connectors incompatibles',
    'Compatibility' => 'Compatibilitat',
    'Permissions and ownership' => 'Permisos i propietat',
    'Priorities' => 'Prioritats',
    'Close this window' => 'Tanca aquesta finestra',
    'Unable to upload this file.' => 'No es pot carregar aquest arxiu.',
    'Import tasks' => 'Importació de tasques',
    'Choose a project' => 'Tria un projecte',
    'Profile' => 'Perfil',
    'Application role' => 'Rol d\'aplicació',
    '%d invitations were sent.' => 'S\'han enviat %d invitacions.',
    '%d invitation was sent.' => 'S\'han enviat %d invitacions.',
    'Unable to create this user.' => 'No es pot crear aquest usuari.',
    'Kanboard Invitation' => 'Invitació Kanboard',
    'Visible on dashboard' => 'Visible al tauler',
    'Created at:' => 'Creat el:',
    'Updated at:' => 'Actualitzat a:',
    'There is no custom filter.' => 'No hi ha cap filtre personal.',
    'New User' => 'Nou usuari',
    'Authentication' => 'Autenticació',
    'If checked, this user will use a third-party system for authentication.' => 'Si s\'activa, aquest usuari utilitzarà un sistema de tercers per a l\'autenticació.',
    'The password is necessary only for local users.' => 'La contrasenya és necessària només per als usuaris locals.',
    'You have been invited to register on Kanboard.' => 'T\'han convidat a inscriure\'t al Kanboard.',
    'Click here to join your team' => 'Fes clic aquí per unir-te a l\'equip',
    'Invite people' => 'Convidar a més gent',
    'Emails' => 'Correus electrònics',
    'Enter one email address by line.' => 'Introdueix una adreça de correu electrònic per línia.',
    'Add these people to this project' => 'Afegeix a aquestes persones a aquest projecte',
    'Add this person to this project' => 'Afegeix aquesta persona a aquest projecte',
    'Sign-up' => 'Registra\'t',
    'Credentials' => 'Credencials',
    'New user' => 'Nou usuari',
    'This username is already taken' => 'Aquest nom d\'usuari ja està en ús',
    'Your profile must have a valid email address.' => 'El teu perfil ha de tenir una adreça de correu electrònic vàlida.',
    'TRL - Turkish Lira' => 'TRL - Lira turca',
    'The project email is optional and could be used by several plugins.' => 'El correu electrònic del projecte és opcional i pot ser utilitzat per diversos connectors.',
    'The project email must be unique across all projects' => 'El correu electrònic del projecte ha de ser únic en tots els projectes',
    'The email configuration has been disabled by the administrator.' => 'La configuració de correu electrònic ha estat desactivat per l\'administrador.',
    'Close this project' => 'Tanca aquest projecte',
    'Open this project' => 'Obre aquest projecte',
    'Close a project' => 'Tanca un projecte',
    // 'Do you really want to close this project: "%s"?' => '',
    'Reopen a project' => 'Torna a obrir un projecte',
    // 'Do you really want to reopen this project: "%s"?' => '',
    'This project is open' => 'Aquest projecte està obert',
    'This project is closed' => 'Aquest projecte està tancat',
    'Unable to upload files, check the permissions of your data folder.' => 'No es pot pujar arxius, comprovar els permisos de la carpeta de dades.',
    'Another category with the same name exists in this project' => 'Una altra categoria amb el mateix nom existeix en aquest projecte',
    'Comment sent by email successfully.' => 'Comentar enviat per correu electrònic amb èxit.',
    // 'Sent by email to "%s" (%s)' => '',
    'Unable to read uploaded file.' => 'No es pot llegir el fitxer pujat.',
    'Database uploaded successfully.' => 'Base de dades carregat correctament.',
    'Task sent by email successfully.' => 'Tasca enviat per correu electrònic amb èxit.',
    'There is no category in this project.' => 'No hi ha una categoria en aquest projecte.',
    'Send by email' => 'Envia per correu electrònic',
    'Create and send a comment by email' => 'Per crear i enviar un comentari per correu electrònic',
    'Subject' => 'Tema',
    'Upload the database' => 'Puja la base de dades',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Es podia pujar la base de dades SQLite prèviament descarregat (format gzip).',
    'Database file' => 'arxiu de base',
    'Upload' => 'Pujar',
    'Your project must have at least one active swimlane.' => 'El seu projecte ha de tenir com a mínim un swimlane actiu.',
    'Project: %s' => 'Projecte: %s',
    // 'Automatic action not found: "%s"' => '',
    '%d projects' => '%d projectes',
    '%d project' => '%d projecte',
    'There is no project.' => 'No hi ha cap projecte.',
    'Sort' => 'Ordena',
    'Project ID' => 'identificació del projecte',
    'Project name' => 'Nom del projecte',
    'Public' => 'Públic',
    'Personal' => 'Privat',
    '%d tasks' => '%d tasques',
    '%d task' => '%d tasca',
    'Task ID' => 'ID de tasca',
    'Assign automatically a color when due date is expired' => 'Assignar automàticament un color quan ha caducat la data de venciment',
    'Total score in this column across all swimlanes' => 'Puntuació total d\'aquesta columna a través de tots swimlanes',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Pes Argentí',
    'COP - Colombian Peso' => 'COP - Pes colombià',
    '%d groups' => '%d grups',
    '%d group' => '%d grup',
    'Group ID' => 'ID de grup',
    'External ID' => 'Identificació externa',
    '%d users' => '%d usuaris',
    '%d user' => '%d usuari',
    'Hide subtasks' => 'Amaga subtasques',
    'Show subtasks' => 'Mostra subtasques',
    'Authentication Parameters' => 'Paràmetres d\'autenticació',
    'API Access' => 'Accés API',
    'No users found.' => 'No es van trobar usuaris.',
    'User ID' => 'ID d\'usuari',
    'Notifications are activated' => 'Notificacions habilitades',
    'Notifications are disabled' => 'Notificacions inhabilitades',
    'User disabled' => 'Usuari deshabilitat',
    '%d notifications' => '%d notificacions',
    '%d notification' => '%d notificació',
    'There is no external integration installed.' => 'No hi ha integració externa instal·lada.',
    'You are not allowed to update tasks assigned to someone else.' => 'No se li permet posar al dia les tasques assignades a una altra persona.',
    'You are not allowed to change the assignee.' => 'No se li permet canviar el assignat.',
    'Task suppression is not permitted' => 'No es permet la supressió de tasques',
    'Changing assignee is not permitted' => 'No es permet el canvi de assignatari',
    'Update only assigned tasks is permitted' => 'Actualitzar les tasques assignades només es permet',
    'Only for tasks assigned to the current user' => 'Només per a les tasques assignades a l\'usuari actual',
    'My projects' => 'Els meus projectes',
    'You are not a member of any project.' => 'No és membre de cap projecte.',
    'My subtasks' => 'Les meves subtasques',
    '%d subtasks' => '%d subtasques',
    '%d subtask' => '%d subtasca',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Only moving task between those columns is permitted for tasks assigned to the current user',
    '[DUPLICATE]' => '[DUPLICATE]',
    // 'DKK - Danish Krona' => '',
    // 'Remove user from group' => '',
    // 'Assign the task to its creator' => '',
    // 'This task was sent by email to "%s" with subject "%s".' => '',
    // 'Predefined Email Subjects' => '',
    // 'Write one subject by line.' => '',
    // 'Create another link' => '',
    // 'BRL - Brazilian Real' => '',
    // 'Add a new Kanboard task' => '',
    // 'Subtask not started' => '',
    // 'Subtask currently in progress' => '',
    // 'Subtask completed' => '',
    // 'Subtask added successfully.' => '',
    // '%d subtasks added successfully.' => '',
    // 'Enter one subtask by line.' => '',
    // 'Predefined Contents' => '',
    // 'Predefined contents' => '',
    // 'Predefined Task Description' => '',
    // 'Do you really want to remove this template? "%s"' => '',
    // 'Add predefined task description' => '',
    // 'Predefined Task Descriptions' => '',
    // 'Template created successfully.' => '',
    // 'Unable to create this template.' => '',
    // 'Template updated successfully.' => '',
    // 'Unable to update this template.' => '',
    // 'Template removed successfully.' => '',
    // 'Unable to remove this template.' => '',
    // 'Template for the task description' => '',
    // 'The start date is greater than the end date' => '',
    // 'Tags must be separated by a comma' => '',
    // 'Only the task title is required' => '',
    // 'Creator Username' => '',
    // 'Color Name' => '',
    // 'Column Name' => '',
    // 'Swimlane Name' => '',
    // 'Time Estimated' => '',
    // 'Time Spent' => '',
    // 'External Link' => '',
    // 'This feature enables the iCal feed, RSS feed and the public board view.' => '',
    // 'Stop the timer of all subtasks when moving a task to another column' => '',
    // 'Subtask Title' => '',
    // 'Add a subtask and activate the timer when moving a task to another column' => '',
    // 'days' => '',
    // 'minutes' => '',
    // 'seconds' => '',
    // 'Assign automatically a color when preset start date is reached' => '',
    // 'Move the task to another column once a predefined start date is reached' => '',
    // 'This task is now linked to the task %s with the relation "%s"' => '',
    // 'The link with the relation "%s" to the task %s has been removed' => '',
    // 'Custom Filter:' => '',
    // 'Unable to find this group.' => '',
    // '%s moved the task #%d to the column "%s"' => '',
    // '%s moved the task #%d to the position %d in the column "%s"' => '',
    // '%s moved the task #%d to the swimlane "%s"' => '',
    // '%sh spent' => '',
    // '%sh estimated' => '',
    // 'Select All' => '',
    // 'Unselect All' => '',
    // 'Apply action' => '',
    // 'Move selected tasks to another column or swimlane' => '',
    // 'Edit tasks in bulk' => '',
    // 'Choose the properties that you would like to change for the selected tasks.' => '',
    // 'Configure this project' => '',
    // 'Start now' => '',
    // '%s removed a file from the task #%d' => '',
    // 'Attachment removed from task #%d: %s' => '',
    // 'No color' => '',
    // 'Attachment removed "%s"' => '',
    // '%s removed a file from the task %s' => '',
    // 'Move the task to another swimlane when assigned to a user' => '',
    // 'Destination swimlane' => '',
    // 'Assign a category when the task is moved to a specific swimlane' => '',
    // 'Move the task to another swimlane when the category is changed' => '',
    // 'Reorder this column by priority (ASC)' => '',
    // 'Reorder this column by priority (DESC)' => '',
    // 'Reorder this column by assignee and priority (ASC)' => '',
    // 'Reorder this column by assignee and priority (DESC)' => '',
    // 'Reorder this column by assignee (A-Z)' => '',
    // 'Reorder this column by assignee (Z-A)' => '',
    // 'Reorder this column by due date (ASC)' => '',
    // 'Reorder this column by due date (DESC)' => '',
    // 'Reorder this column by id (ASC)' => '',
    // 'Reorder this column by id (DESC)' => '',
    // '%s moved the task #%d "%s" to the project "%s"' => '',
    // 'Task #%d "%s" has been moved to the project "%s"' => '',
    // 'Move the task to another column when the due date is less than a certain number of days' => '',
    // 'Automatically update the start date when the task is moved away from a specific column' => '',
    // 'HTTP Client:' => '',
    // 'Assigned' => '',
    // 'Task limits apply to each swimlane individually' => '',
    // 'Column task limits apply to each swimlane individually' => '',
    // 'Column task limits are applied to each swimlane individually' => '',
    // 'Column task limits are applied across swimlanes' => '',
    // 'Task limit: ' => '',
    // 'Change to global tag' => '',
    // 'Do you really want to make the tag "%s" global?' => '',
    // 'Enable global tags for this project' => '',
    // 'Group membership(s):' => '',
    // '%s is a member of the following group(s): %s' => '',
    // '%d/%d group(s) shown' => '',
    // 'Subtask creation or modification' => '',
    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
    // 'Comment' => '',
    // 'Collapse vertically' => '',
    // 'Expand vertically' => '',
    // 'MXN - Mexican Peso' => '',
    // 'Estimated vs actual time per column' => '',
    // 'HUF - Hungarian Forint' => '',
    // 'XBT - Bitcoin' => '',
    // 'You must select a file to upload as your avatar!' => '',
    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
    // 'Automatically set the due date when the task is moved away from a specific column' => '',
    // 'No other projects found.' => '',
    // 'Please choose a project you want to copy the tasks from.' => '',
    // 'Import Tasks' => '',
    // 'Copy' => '',
    // 'Tasks copied successfully.' => '',
    // 'Unable to copy tasks.' => '',
    // 'Theme' => '',
    // 'Theme:' => '',
    // 'Light theme' => '',
    // 'Dark theme' => '',
    // 'Automatic theme - Sync with system' => '',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
